@@ -510,7 +510,7 @@ $lang['back_top'] = 'Zur&uuml;ck zur FormBuilder-Hauptseite';
 $lang['title_headers_to_modify'] = 'Welche Email-Header sollen diese Eingabe erhalten?';
 $lang['title_blank_invalid'] = 'Leerzeichen nicht als g&uuml;ltigen Eintrag akzeptieren';
 $lang['title_blank_invalid_long'] = 'Bei Pflichtfeldern muss der Benutzer alphanumerische Zeichen statt Leerzeichen eingeben.';
-$lang['title_must_save_order'] = 'Sie m&uuml;ssen einen der &quot;Speichern&quot; Buttons verwenden um die neue Feldreihenfolge zu &uuml;bernehmen.';
+$lang['title_must_save_order'] = 'Sie m&uuml;ssen einen der &bdquo;Speichern&ldquo;-Kn&ouml;pfe verwenden um die neue Feldreihenfolge zu &uuml;bernehmen.';
 $lang['title_html5'] = 'Im Text HTML5-Platzhalter anstatt Javascript verwenden';
 $lang['title_email_cc_address'] = 'Adresse(n), an die eine Kopie gesendet werden soll. Mehrere Adressen durch Kommas trennen.';
 $lang['title_use_bcc'] = 'Blindkopie senden';
@@ -520,8 +520,8 @@ $lang['title_modifies'] = 'Add CC to &quot;%s&quot;';
 $lang['bcc_field'] = '&quot;BCC&quot; recipients';
 $lang['cc_field'] = '&quot;CC&quot; recipients';
 $lang['to_field'] = 'Normal (&quot;To&quot; recipients)';
-$lang['bcc'] = 'BCC';
-$lang['cc'] = 'CC';
+$lang['bcc'] = 'Blindkopie';
+$lang['cc'] = 'Kopie';
 $lang['error_CompanyDirectory_module_not_available'] = 'Das CompanyDirectory-Modul ist nicht verf&uuml;gbar!';
 $lang['option_never'] = 'Niemals';
 $lang['option_user_choice'] = 'Dem Benutzer eine Auswahl anbieten (Kontrollk&auml;stchen)';
